@@ -1,5 +1,5 @@
 // © 2016 and later: Unicode, Inc. and others.
-// License & terms of use: http://www.unicode.org/copyright.html#License
+// License & terms of use: http://www.unicode.org/copyright.html
 /**
 *******************************************************************************
 * Copyright (C) 2006-2014, International Business Machines Corporation and
@@ -55,13 +55,13 @@ public class CharsetCallback {
 
     /*
      * FROM_U_CALLBACK_ESCAPE context option to escape the code unit according to C (\\uXXXX \\UXXXXXXXX)
-     * TO_U_CALLBACK_ESCAPE option to escape the character value accoding to C (\\xXXXX)
+     * TO_U_CALLBACK_ESCAPE option to escape the character value according to C (\\xXXXX)
      */
     private static final String ESCAPE_C        = "C";
 
     /*
      * FROM_U_CALLBACK_ESCAPE context option to escape the code unit according to XML Decimal escape \htmlonly(&amp;#DDDD;)\endhtmlonly
-     * TO_U_CALLBACK_ESCAPE context option to escape the character value accoding to XML Decimal escape \htmlonly(&amp;#DDDD;)\endhtmlonly
+     * TO_U_CALLBACK_ESCAPE context option to escape the character value according to XML Decimal escape \htmlonly(&amp;#DDDD;)\endhtmlonly
      */
     private static final String ESCAPE_XML_DEC  = "D";
 
@@ -90,7 +90,7 @@ public class CharsetCallback {
      * When an ignorable code point is found and is unmappable, the default callbacks
      * will ignore them.
      * For a list of the default ignorable code points, use this link:
-     * https://unicode.org/cldr/utility/list-unicodeset.jsp?a=%5B%3ADI%3A%5D&abb=on&g=&i=
+     * https://util.unicode.org/UnicodeJsps/list-unicodeset.jsp?a=%5B%3ADI%3A%5D&abb=on&g=&i=
      *
      * This list should be sync with the one in ucnv_err.cpp.
      */
@@ -102,7 +102,7 @@ public class CharsetCallback {
             (c == 0x115F) ||
             (c == 0x1160) ||
             (0x17B4 <= c && c <= 0x17B5) ||
-            (0x180B <= c && c <= 0x180E) ||
+            (0x180B <= c && c <= 0x180F) ||
             (0x200B <= c && c <= 0x200F) ||
             (0x202A <= c && c <= 0x202E) ||
             (0x2060 <= c && c <= 0x206F) ||
