@@ -42,6 +42,7 @@ public class MutablePatternModifier implements Modifier, SymbolProvider, MicroPr
     Field field;
     SignDisplay signDisplay;
     boolean perMilleReplacesPercent;
+    boolean approximately;
 
     // Symbol details
     DecimalFormatSymbols symbols;
@@ -89,10 +90,13 @@ public class MutablePatternModifier implements Modifier, SymbolProvider, MicroPr
      *            Whether to force a plus sign on positive numbers.
      * @param perMille
      *            Whether to substitute the percent sign in the pattern with a permille sign.
+     * @param approximately
+     *            Whether to prepend approximately to the sign
      */
-    public void setPatternAttributes(SignDisplay signDisplay, boolean perMille) {
+    public void setPatternAttributes(SignDisplay signDisplay, boolean perMille, boolean approximately) {
         this.signDisplay = signDisplay;
         this.perMilleReplacesPercent = perMille;
+        this.approximately = approximately;
     }
 
     /**
@@ -375,6 +379,7 @@ public class MutablePatternModifier implements Modifier, SymbolProvider, MicroPr
         PatternStringUtils.patternInfoToStringBuilder(patternInfo,
                 isPrefix,
                 PatternStringUtils.resolveSignDisplay(signDisplay, signum),
+                approximately,
                 plural,
                 perMilleReplacesPercent,
                 currentAffix);
@@ -390,36 +395,14 @@ public class MutablePatternModifier implements Modifier, SymbolProvider, MicroPr
             return symbols.getMinusSignString();
         case AffixUtils.TYPE_PLUS_SIGN:
             return symbols.getPlusSignString();
+        case AffixUtils.TYPE_APPROXIMATELY_SIGN:
+            return symbols.getApproximatelySignString();
         case AffixUtils.TYPE_PERCENT:
             return symbols.getPercentString();
         case AffixUtils.TYPE_PERMILLE:
             return symbols.getPerMillString();
         case AffixUtils.TYPE_CURRENCY_SINGLE:
-            // UnitWidth ISO, HIDDEN, or NARROW overrides the singular currency symbol.
-            if (unitWidth == UnitWidth.ISO_CODE) {
-                return currency.getCurrencyCode();
-            } else if (unitWidth == UnitWidth.HIDDEN) {
-                return "";
-            } else {
-                int selector;
-                switch (unitWidth) {
-                    case SHORT:
-                        selector = Currency.SYMBOL_NAME;
-                        break;
-                    case NARROW:
-                        selector = Currency.NARROW_SYMBOL_NAME;
-                        break;
-                    case FORMAL:
-                        selector = Currency.FORMAL_SYMBOL_NAME;
-                        break;
-                    case VARIANT:
-                        selector = Currency.VARIANT_SYMBOL_NAME;
-                        break;
-                    default:
-                        throw new AssertionError();
-                }
-                return currency.getName(symbols.getULocale(), selector, null);
-            }
+            return getCurrencySymbolForUnitWidth();
         case AffixUtils.TYPE_CURRENCY_DOUBLE:
             return currency.getCurrencyCode();
         case AffixUtils.TYPE_CURRENCY_TRIPLE:
@@ -437,4 +420,35 @@ public class MutablePatternModifier implements Modifier, SymbolProvider, MicroPr
             throw new AssertionError();
         }
     }
+
+    /**
+     * Returns the currency symbol for the unit width specified in setSymbols()
+     */
+    public String getCurrencySymbolForUnitWidth() {
+        // UnitWidth ISO, HIDDEN, or NARROW overrides the singular currency symbol.
+        if (unitWidth == UnitWidth.ISO_CODE) {
+            return currency.getCurrencyCode();
+        } else if (unitWidth == UnitWidth.HIDDEN) {
+            return "";
+        } else {
+            int selector;
+            switch (unitWidth) {
+                case SHORT:
+                    selector = Currency.SYMBOL_NAME;
+                    break;
+                case NARROW:
+                    selector = Currency.NARROW_SYMBOL_NAME;
+                    break;
+                case FORMAL:
+                    selector = Currency.FORMAL_SYMBOL_NAME;
+                    break;
+                case VARIANT:
+                    selector = Currency.VARIANT_SYMBOL_NAME;
+                    break;
+                default:
+                    throw new AssertionError();
+            }
+            return currency.getName(symbols.getULocale(), selector, null);
+        }
+    }
 }
