@@ -27,4 +27,8 @@ public class PrefixInfixSuffixLengthHelper {
     public int index3() {
         return lengthPrefix + length1 + lengthInfix + length2;
     }
+
+    public int index4() {
+        return lengthPrefix + length1 + lengthInfix + length2 + lengthSuffix;
+    }
 }
