@@ -35,7 +35,6 @@ import com.ibm.icu.text.UnicodeSet;
  * A unit such as length, mass, volume, currency, etc.  A unit is
  * coupled with a numeric amount to produce a Measure. MeasureUnit objects are immutable.
  * All subclasses must guarantee that. (However, subclassing is discouraged.)
-
  *
  * @see com.ibm.icu.util.Measure
  * @author Alan Liu
@@ -76,226 +75,258 @@ public class MeasureUnit implements Serializable {
 
     /**
      * Enumeration for unit complexity. There are three levels:
-     * <p>
-     * - SINGLE: A single unit, optionally with a power and/or SI prefix. Examples: hectare,
-     * square-kilometer, kilojoule, one-per-second.
-     * - COMPOUND: A unit composed of the product of multiple single units. Examples:
-     * meter-per-second, kilowatt-hour, kilogram-meter-per-square-second.
-     * - MIXED: A unit composed of the sum of multiple single units. Examples: foot-and-inch,
-     * hour-and-minute-and-second, degree-and-arcminute-and-arcsecond.
-     * <p>
+     * <ul>
+     * <li>SINGLE: A single unit, optionally with a power and/or SI or binary prefix.
+     * Examples: hectare, square-kilometer, kilojoule, per-second, mebibyte.</li>
+     * <li>COMPOUND: A unit composed of the product of multiple single units. Examples:
+     * meter-per-second, kilowatt-hour, kilogram-meter-per-square-second.</li>
+     * <li>MIXED: A unit composed of the sum of multiple single units. Examples: foot-and-inch,
+     * hour-and-minute-and-second, degree-and-arcminute-and-arcsecond.</li>
+     * </ul>
      * The complexity determines which operations are available. For example, you cannot set the power
-     * or SI prefix of a compound unit.
+     * or prefix of a compound unit.
      *
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 68
      */
     public enum Complexity {
         /**
          * A single unit, like kilojoule.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 68
          */
         SINGLE,
 
         /**
          * A compound unit, like meter-per-second.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 68
          */
         COMPOUND,
 
         /**
          * A mixed unit, like hour-and-minute.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 68
          */
         MIXED
     }
 
     /**
-     * Enumeration for SI prefixes, such as "kilo".
+     * Enumeration for SI and binary prefixes, e.g. "kilo-", "nano-", "mebi-".
      *
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 69
      */
-    public enum SIPrefix {
+    public enum MeasurePrefix {
 
         /**
          * SI prefix: yotta, 10^24.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        YOTTA(24, "yotta"),
+        YOTTA(24, "yotta", 10),
 
         /**
          * SI prefix: zetta, 10^21.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        ZETTA(21, "zetta"),
+        ZETTA(21, "zetta", 10),
 
         /**
          * SI prefix: exa, 10^18.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        EXA(18, "exa"),
+        EXA(18, "exa", 10),
 
         /**
          * SI prefix: peta, 10^15.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        PETA(15, "peta"),
+        PETA(15, "peta", 10),
 
         /**
          * SI prefix: tera, 10^12.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        TERA(12, "tera"),
+        TERA(12, "tera", 10),
 
         /**
          * SI prefix: giga, 10^9.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        GIGA(9, "giga"),
+        GIGA(9, "giga", 10),
 
         /**
          * SI prefix: mega, 10^6.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        MEGA(6, "mega"),
+        MEGA(6, "mega", 10),
 
         /**
          * SI prefix: kilo, 10^3.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        KILO(3, "kilo"),
+        KILO(3, "kilo", 10),
 
         /**
          * SI prefix: hecto, 10^2.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        HECTO(2, "hecto"),
+        HECTO(2, "hecto", 10),
 
         /**
          * SI prefix: deka, 10^1.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        DEKA(1, "deka"),
+        DEKA(1, "deka", 10),
 
         /**
          * The absence of an SI prefix.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        ONE(0, ""),
+        ONE(0, "", 10),
 
         /**
          * SI prefix: deci, 10^-1.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        DECI(-1, "deci"),
+        DECI(-1, "deci", 10),
 
         /**
          * SI prefix: centi, 10^-2.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        CENTI(-2, "centi"),
+        CENTI(-2, "centi", 10),
 
         /**
          * SI prefix: milli, 10^-3.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        MILLI(-3, "milli"),
+        MILLI(-3, "milli", 10),
 
         /**
          * SI prefix: micro, 10^-6.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        MICRO(-6, "micro"),
+        MICRO(-6, "micro", 10),
 
         /**
          * SI prefix: nano, 10^-9.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        NANO(-9, "nano"),
+        NANO(-9, "nano", 10),
 
         /**
          * SI prefix: pico, 10^-12.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        PICO(-12, "pico"),
+        PICO(-12, "pico", 10),
 
         /**
          * SI prefix: femto, 10^-15.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        FEMTO(-15, "femto"),
+        FEMTO(-15, "femto", 10),
 
         /**
          * SI prefix: atto, 10^-18.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        ATTO(-18, "atto"),
+        ATTO(-18, "atto", 10),
 
         /**
          * SI prefix: zepto, 10^-21.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        ZEPTO(-21, "zepto"),
+        ZEPTO(-21, "zepto", 10),
 
         /**
          * SI prefix: yocto, 10^-24.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
          */
-        YOCTO(-24, "yocto");
+        YOCTO(-24, "yocto", 10),
 
+        /**
+         * IEC binary prefix: kibi, 1024^1.
+         *
+         * @stable ICU 69
+         */
+        KIBI(1, "kibi", 1024),
+
+        /**
+         * IEC binary prefix: mebi, 1024^2.
+         *
+         * @stable ICU 69
+         */
+        MEBI(2, "mebi", 1024),
+
+        /**
+         * IEC binary prefix: gibi, 1024^3.
+         *
+         * @stable ICU 69
+         */
+        GIBI(3, "gibi", 1024),
+
+        /**
+         * IEC binary prefix: tebi, 1024^4.
+         *
+         * @stable ICU 69
+         */
+        TEBI(4, "tebi", 1024),
+
+        /**
+         * IEC binary prefix: pebi, 1024^5.
+         *
+         * @stable ICU 69
+         */
+        PEBI(5, "pebi", 1024),
+
+        /**
+         * IEC binary prefix: exbi, 1024^6.
+         *
+         * @stable ICU 69
+         */
+        EXBI(6, "exbi", 1024),
+
+        /**
+         * IEC binary prefix: zebi, 1024^7.
+         *
+         * @stable ICU 69
+         */
+        ZEBI(7, "zebi", 1024),
+
+        /**
+         * IEC binary prefix: yobi, 1024^8.
+         *
+         * @stable ICU 69
+         */
+        YOBI(8, "yobi", 1024);
+
+        private final int base;
         private final int power;
         private final String identifier;
 
-        SIPrefix(int power, String identifier) {
+        MeasurePrefix(int power, String identifier, int base) {
+            this.base = base;
             this.power = power;
             this.identifier = identifier;
         }
@@ -312,10 +343,22 @@ public class MeasureUnit implements Serializable {
         }
 
         /**
-         * Returns the power of 10 of the prefix. For example, if the prefix is "centi", the power will be -2.
+         * Returns the base of the prefix. For example:
+         * - if the prefix is "centi", the base will be 10.
+         * - if the prefix is "gibi", the base will be 1024.
          *
-         * @draft ICU 68
-         * @provisional This API might change or be removed in a future release.
+         * @stable ICU 69
+         */
+        public int getBase() {
+            return base;
+        }
+
+        /**
+         * Returns the power of the prefix. For example:
+         * - if the prefix is "centi", the power will be -2.
+         * - if the prefix is "gibi", the power will be 3 (for base 1024).
+         *
+         * @stable ICU 69
          */
         public int getPower() {
             return power;
@@ -333,8 +376,9 @@ public class MeasureUnit implements Serializable {
     }
 
     /**
-     * Construct a MeasureUnit from a CLDR Unit Identifier, defined in UTS 35.
-     * Validates and canonicalizes the identifier.
+     * Construct a MeasureUnit from a CLDR Core Unit Identifier, defined in UTS
+     * 35. (Core unit identifiers and mixed unit identifiers are supported, long
+     * unit identifiers are not.) Validates and canonicalizes the identifier.
      *
      * Note: dimensionless <code>MeasureUnit</code> is <code>null</code>
      *
@@ -342,10 +386,9 @@ public class MeasureUnit implements Serializable {
      * MeasureUnit example = MeasureUnit::forIdentifier("furlong-per-nanosecond")
      * </pre>
      *
-     * @param identifier The CLDR Sequence Unit Identifier
+     * @param identifier CLDR Unit Identifier
      * @throws IllegalArgumentException if the identifier is invalid.
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 68
      */
     public static MeasureUnit forIdentifier(String identifier) {
         if (identifier == null || identifier.isEmpty()) {
@@ -399,11 +442,10 @@ public class MeasureUnit implements Serializable {
     }
 
     /**
-     * Gets the CLDR Unit Identifier for this MeasureUnit, as defined in UTS 35.
+     * Get CLDR Unit Identifier for this MeasureUnit, as defined in UTS 35.
      *
      * @return The string form of this unit.
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 68
      */
     public String getIdentifier() {
         String result = measureUnitImpl == null ? getSubtype() : measureUnitImpl.getIdentifier();
@@ -414,8 +456,7 @@ public class MeasureUnit implements Serializable {
      * Compute the complexity of the unit. See Complexity for more information.
      *
      * @return The unit complexity.
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 68
      */
     public Complexity getComplexity() {
         if (measureUnitImpl == null) {
@@ -426,41 +467,39 @@ public class MeasureUnit implements Serializable {
     }
 
     /**
-     * Creates a MeasureUnit which is this SINGLE unit augmented with the specified SI prefix.
-     * For example, SI_PREFIX_KILO for "kilo".
-     * May return this if this unit already has that prefix.
+     * Creates a MeasureUnit which is this SINGLE unit augmented with the specified prefix.
+     * For example, MeasurePrefix.KILO for "kilo", or MeasurePrefix.KIBI for "kibi".
+     * May return {@code this} if this unit already has that prefix.
      * <p>
-     * There is sufficient locale data to format all standard SI prefixes.
+     * There is sufficient locale data to format all standard prefixes.
      * <p>
      * NOTE: Only works on SINGLE units. If this is a COMPOUND or MIXED unit, an error will
-     * occur. For more information, see `Complexity`.
+     * occur. For more information, {@link Complexity}.
      *
-     * @param prefix The SI prefix, from SIPrefix.
+     * @param prefix The prefix, from MeasurePrefix.
      * @return A new SINGLE unit.
      * @throws UnsupportedOperationException if this unit is a COMPOUND or MIXED unit.
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 69
      */
-    public MeasureUnit withSIPrefix(SIPrefix prefix) {
+    public MeasureUnit withPrefix(MeasurePrefix prefix) {
         SingleUnitImpl singleUnit = getSingleUnitImpl();
-        singleUnit.setSiPrefix(prefix);
+        singleUnit.setPrefix(prefix);
         return singleUnit.build();
     }
 
     /**
-     * Returns the current SI prefix of this SINGLE unit. For example, if the unit has the SI prefix
-     * "kilo", then SI_PREFIX_KILO is returned.
+     * Returns the current SI or binary prefix of this SINGLE unit. For example,
+     * if the unit has the prefix "kilo", then MeasurePrefix.KILO is returned.
      * <p>
-     * NOTE: Only works on SINGLE units. If this is a COMPOUND or MIXED unit, an error will
-     * occur. For more information, see `Complexity`.
+     * NOTE: Only works on SINGLE units. If this is a COMPOUND or MIXED unit, an
+     * error will occur. For more information, {@link Complexity}.
      *
-     * @return The SI prefix of this SINGLE unit, from SIPrefix.
+     * @return The prefix of this SINGLE unit, from MeasurePrefix.
      * @throws UnsupportedOperationException if the unit is COMPOUND or MIXED.
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 69
      */
-    public SIPrefix getSIPrefix() {
-        return getSingleUnitImpl().getSiPrefix();
+    public MeasurePrefix getPrefix() {
+        return getSingleUnitImpl().getPrefix();
     }
 
     /**
@@ -468,12 +507,11 @@ public class MeasureUnit implements Serializable {
      * then 2 is returned.
      * <p>
      * NOTE: Only works on SINGLE units. If this is a COMPOUND or MIXED unit, an exception will be thrown.
-     * For more information, see `Complexity`.
+     * For more information, {@link Complexity}.
      *
      * @return The dimensionality (power) of this simple unit.
      * @throws UnsupportedOperationException if the unit is COMPOUND or MIXED.
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 68
      */
     public int getDimensionality() {
         return getSingleUnitImpl().getDimensionality();
@@ -484,13 +522,12 @@ public class MeasureUnit implements Serializable {
      * (power). For example, if dimensionality is 2, the unit will be squared.
      * <p>
      * NOTE: Only works on SINGLE units. If this is a COMPOUND or MIXED unit, an exception is thrown.
-     * For more information, see `Complexity`.
+     * For more information, {@link Complexity}.
      *
      * @param dimensionality The dimensionality (power).
      * @return A new SINGLE unit.
      * @throws UnsupportedOperationException if the unit is COMPOUND or MIXED.
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 68
      */
     public MeasureUnit withDimensionality(int dimensionality) {
         SingleUnitImpl singleUnit = getSingleUnitImpl();
@@ -504,12 +541,11 @@ public class MeasureUnit implements Serializable {
      * For example, if the receiver is "meter-per-second", the unit "second-per-meter" is returned.
      * <p>
      * NOTE: Only works on SINGLE and COMPOUND units. If this is a MIXED unit, an error will
-     * occur. For more information, see `Complexity`.
+     * occur. For more information, {@link Complexity}.
      *
      * @return The reciprocal of the target unit.
      * @throws UnsupportedOperationException if the unit is MIXED.
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 68
      */
     public MeasureUnit reciprocal() {
         MeasureUnitImpl measureUnit = getCopyOfMeasureUnitImpl();
@@ -527,13 +563,12 @@ public class MeasureUnit implements Serializable {
      * unit "kilowatt-hour-per-day" is returned.
      * <p>
      * NOTE: Only works on SINGLE and COMPOUND units. If either unit (receivee and argument) is a
-     * MIXED unit, an error will occur. For more information, see `Complexity`.
+     * MIXED unit, an error will occur. For more information, {@link Complexity}.
      *
      * @param other The MeasureUnit to multiply with the target.
      * @return The product of the target unit with the provided unit.
      * @throws UnsupportedOperationException if the unit is MIXED.
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 68
      */
     public MeasureUnit product(MeasureUnit other) {
         MeasureUnitImpl implCopy = getCopyOfMeasureUnitImpl();
@@ -542,7 +577,7 @@ public class MeasureUnit implements Serializable {
             return implCopy.build();
         }
 
-        final MeasureUnitImpl otherImplRef = other.getMayBeReferenceOfMeasureUnitImpl();
+        final MeasureUnitImpl otherImplRef = other.getMaybeReferenceOfMeasureUnitImpl();
         if (implCopy.getComplexity() == Complexity.MIXED || otherImplRef.getComplexity() == Complexity.MIXED) {
             throw new UnsupportedOperationException();
         }
@@ -560,18 +595,18 @@ public class MeasureUnit implements Serializable {
      * <p>
      * Examples:
      * - Given "meter-kilogram-per-second", three units will be returned: "meter",
-     * "kilogram", and "one-per-second".
+     * "kilogram", and "per-second".
      * - Given "hour+minute+second", three units will be returned: "hour", "minute",
      * and "second".
      * <p>
      * If this is a SINGLE unit, a list of length 1 will be returned.
      *
      * @return An unmodifiable list of single units
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
+     * @stable ICU 68
      */
     public List<MeasureUnit> splitToSingleUnits() {
-        final ArrayList<SingleUnitImpl> singleUnits = getMayBeReferenceOfMeasureUnitImpl().getSingleUnits();
+        final ArrayList<SingleUnitImpl> singleUnits =
+            getMaybeReferenceOfMeasureUnitImpl().getSingleUnits();
         List<MeasureUnit> result = new ArrayList<>(singleUnits.size());
         for (SingleUnitImpl singleUnit : singleUnits) {
             result.add(singleUnit.build());
@@ -614,7 +649,8 @@ public class MeasureUnit implements Serializable {
      */
     @Override
     public String toString() {
-        return type + "-" + subType;
+        String result = measureUnitImpl == null ? type + "-" + subType : measureUnitImpl.getIdentifier();
+        return result == null ? "" : result;
     }
 
     /**
@@ -622,7 +658,7 @@ public class MeasureUnit implements Serializable {
      *
      * @stable ICU 53
      */
-    public synchronized static Set<String> getAvailableTypes() {
+    public static Set<String> getAvailableTypes() {
         populateCache();
         return Collections.unmodifiableSet(cache.keySet());
     }
@@ -633,7 +669,7 @@ public class MeasureUnit implements Serializable {
      * @return the available units for type. Returned set is unmodifiable.
      * @stable ICU 53
      */
-    public synchronized static Set<MeasureUnit> getAvailable(String type) {
+    public static Set<MeasureUnit> getAvailable(String type) {
         populateCache();
         Map<String, MeasureUnit> units = cache.get(type);
         // Train users not to modify returned set from the start giving us more
@@ -691,7 +727,12 @@ public class MeasureUnit implements Serializable {
         return MeasureUnit.addUnit(type, subType, factory);
     }
 
-    private static MeasureUnit findBySubType(String subType) {
+    /**
+     * @internal
+     * @deprecated This API is ICU internal only.
+     */
+    @Deprecated
+    public static MeasureUnit findBySubType(String subType) {
         populateCache();
         for (Map<String, MeasureUnit> unitsForType : cache.values()) {
             if (unitsForType.containsKey(subType)) {
@@ -785,11 +826,9 @@ public class MeasureUnit implements Serializable {
      * Adding of others is deferred until later to avoid circular static init
      * dependencies with classes Currency and TimeUnit.
      *
-     * <p>Synchronization: this function must be called from static synchronized methods only.
-     *
      * @internal
      */
-    static private void populateCache() {
+    static synchronized private void populateCache() {
         if (cacheIsPopulated) {
             return;
         }
@@ -848,7 +887,7 @@ public class MeasureUnit implements Serializable {
 // the "End generated MeasureUnit constants" comment is auto generated code
 // and must not be edited manually. For instructions on how to correctly
 // update this code, refer to:
-// http://site.icu-project.org/design/formatting/measureformat/updating-measure-unit
+// docs/processes/release/tasks/updating-measure-unit.md
 //
     // Start generated MeasureUnit constants
 
@@ -954,12 +993,24 @@ public class MeasureUnit implements Serializable {
      */
     public static final MeasureUnit SQUARE_YARD = MeasureUnit.internalGetInstance("area", "square-yard");
 
+    /**
+     * Constant for unit of concentr: item
+     * @stable ICU 70
+     */
+    public static final MeasureUnit ITEM = MeasureUnit.internalGetInstance("concentr", "item");
+
     /**
      * Constant for unit of concentr: karat
      * @stable ICU 54
      */
     public static final MeasureUnit KARAT = MeasureUnit.internalGetInstance("concentr", "karat");
 
+    /**
+     * Constant for unit of concentr: milligram-ofglucose-per-deciliter
+     * @stable ICU 69
+     */
+    public static final MeasureUnit MILLIGRAM_OFGLUCOSE_PER_DECILITER = MeasureUnit.internalGetInstance("concentr", "milligram-ofglucose-per-deciliter");
+
     /**
      * Constant for unit of concentr: milligram-per-deciliter
      * @stable ICU 57
@@ -1158,6 +1209,12 @@ public class MeasureUnit implements Serializable {
      */
     public static final MeasureUnit NANOSECOND = MeasureUnit.internalGetInstance("duration", "nanosecond");
 
+    /**
+     * Constant for unit of duration: quarter
+     * @draft ICU 72
+     */
+    public static final MeasureUnit QUARTER = MeasureUnit.internalGetInstance("duration", "quarter");
+
     /**
      * Constant for unit of duration: second
      * @stable ICU 4.0
@@ -1266,6 +1323,12 @@ public class MeasureUnit implements Serializable {
      */
     public static final MeasureUnit THERM_US = MeasureUnit.internalGetInstance("energy", "therm-us");
 
+    /**
+     * Constant for unit of force: kilowatt-hour-per-100-kilometer
+     * @stable ICU 70
+     */
+    public static final MeasureUnit KILOWATT_HOUR_PER_100_KILOMETER = MeasureUnit.internalGetInstance("force", "kilowatt-hour-per-100-kilometer");
+
     /**
      * Constant for unit of force: newton
      * @stable ICU 64
@@ -1304,9 +1367,8 @@ public class MeasureUnit implements Serializable {
 
     /**
      * Constant for unit of graphics: dot
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit DOT = MeasureUnit.internalGetInstance("graphics", "dot");
 
     /**
@@ -1371,9 +1433,8 @@ public class MeasureUnit implements Serializable {
 
     /**
      * Constant for unit of length: earth-radius
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit EARTH_RADIUS = MeasureUnit.internalGetInstance("length", "earth-radius");
 
     /**
@@ -1486,16 +1547,14 @@ public class MeasureUnit implements Serializable {
 
     /**
      * Constant for unit of light: candela
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit CANDELA = MeasureUnit.internalGetInstance("light", "candela");
 
     /**
      * Constant for unit of light: lumen
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit LUMEN = MeasureUnit.internalGetInstance("light", "lumen");
 
     /**
@@ -1530,9 +1589,8 @@ public class MeasureUnit implements Serializable {
 
     /**
      * Constant for unit of mass: grain
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit GRAIN = MeasureUnit.internalGetInstance("mass", "grain");
 
     /**
@@ -1548,10 +1606,12 @@ public class MeasureUnit implements Serializable {
     public static final MeasureUnit KILOGRAM = MeasureUnit.internalGetInstance("mass", "kilogram");
 
     /**
-     * Constant for unit of mass: metric-ton
+     * Constant for unit of mass: metric-ton (renamed to tonne in CLDR 42 / ICU 72).
+     * Note: In ICU 74 this will be deprecated in favor of TONNE, which is currently
+     * draft but will become stable in ICU 74, and which uses the preferred naming.
      * @stable ICU 54
      */
-    public static final MeasureUnit METRIC_TON = MeasureUnit.internalGetInstance("mass", "metric-ton");
+    public static final MeasureUnit METRIC_TON = MeasureUnit.internalGetInstance("mass", "tonne");
 
     /**
      * Constant for unit of mass: microgram
@@ -1601,6 +1661,12 @@ public class MeasureUnit implements Serializable {
      */
     public static final MeasureUnit TON = MeasureUnit.internalGetInstance("mass", "ton");
 
+    /**
+     * Constant for unit of mass: tonne
+     * @draft ICU 72
+     */
+    public static final MeasureUnit TONNE = MeasureUnit.internalGetInstance("mass", "tonne");
+
     /**
      * Constant for unit of power: gigawatt
      * @stable ICU 54
@@ -1697,6 +1763,12 @@ public class MeasureUnit implements Serializable {
      */
     public static final MeasureUnit POUND_PER_SQUARE_INCH = MeasureUnit.internalGetInstance("pressure", "pound-force-per-square-inch");
 
+    /**
+     * Constant for unit of speed: beaufort
+     * @draft ICU 73
+     */
+    public static final MeasureUnit BEAUFORT = MeasureUnit.internalGetInstance("speed", "beaufort");
+
     /**
      * Constant for unit of speed: kilometer-per-hour
      * @stable ICU 53
@@ -1843,30 +1915,26 @@ public class MeasureUnit implements Serializable {
 
     /**
      * Constant for unit of volume: dessert-spoon
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit DESSERT_SPOON = MeasureUnit.internalGetInstance("volume", "dessert-spoon");
 
     /**
      * Constant for unit of volume: dessert-spoon-imperial
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit DESSERT_SPOON_IMPERIAL = MeasureUnit.internalGetInstance("volume", "dessert-spoon-imperial");
 
     /**
      * Constant for unit of volume: dram
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit DRAM = MeasureUnit.internalGetInstance("volume", "dram");
 
     /**
      * Constant for unit of volume: drop
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit DROP = MeasureUnit.internalGetInstance("volume", "drop");
 
     /**
@@ -1901,9 +1969,8 @@ public class MeasureUnit implements Serializable {
 
     /**
      * Constant for unit of volume: jigger
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit JIGGER = MeasureUnit.internalGetInstance("volume", "jigger");
 
     /**
@@ -1926,9 +1993,8 @@ public class MeasureUnit implements Serializable {
 
     /**
      * Constant for unit of volume: pinch
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit PINCH = MeasureUnit.internalGetInstance("volume", "pinch");
 
     /**
@@ -1951,9 +2017,8 @@ public class MeasureUnit implements Serializable {
 
     /**
      * Constant for unit of volume: quart-imperial
-     * @draft ICU 68
-     * @provisional This API might change or be removed in a future release.
-    */
+     * @stable ICU 68
+     */
     public static final MeasureUnit QUART_IMPERIAL = MeasureUnit.internalGetInstance("volume", "quart-imperial");
 
     /**
@@ -1968,9 +2033,8 @@ public class MeasureUnit implements Serializable {
      */
     public static final MeasureUnit TEASPOON = MeasureUnit.internalGetInstance("volume", "teaspoon");
 
-    // unitPerUnitToSingleUnit no longer in use! TODO: remove from code-generation code.
-
     // End generated MeasureUnit constants
+
     /* Private */
 
     private Object writeReplace() throws ObjectStreamException {
@@ -1982,6 +2046,7 @@ public class MeasureUnit implements Serializable {
      * @return this object as a SingleUnitImpl.
      * @throws UnsupportedOperationException if this object could not be converted to a single unit.
      */
+    // In ICU4C, this is SingleUnitImpl::forMeasureUnit().
     private SingleUnitImpl getSingleUnitImpl() {
         if (measureUnitImpl == null) {
             return MeasureUnitImpl.forIdentifier(getIdentifier()).getSingleUnitImpl();
@@ -1993,8 +2058,11 @@ public class MeasureUnit implements Serializable {
     /**
      *
      * @return this object in a MeasureUnitImpl form.
+     * @internal
+     * @deprecated This API is ICU internal only.
      */
-    private MeasureUnitImpl getCopyOfMeasureUnitImpl() {
+    @Deprecated
+    public MeasureUnitImpl getCopyOfMeasureUnitImpl() {
         return this.measureUnitImpl == null ?
                 MeasureUnitImpl.forIdentifier(getIdentifier()) :
                 this.measureUnitImpl.copy();
@@ -2004,7 +2072,7 @@ public class MeasureUnit implements Serializable {
      *
      * @return this object in a MeasureUnitImpl form.
      */
-    private MeasureUnitImpl getMayBeReferenceOfMeasureUnitImpl(){
+    private MeasureUnitImpl getMaybeReferenceOfMeasureUnitImpl() {
         return this.measureUnitImpl == null ?
                 MeasureUnitImpl.forIdentifier(getIdentifier()) :
                 this.measureUnitImpl;
