@@ -199,6 +199,18 @@ public final class VersionInfo implements Comparable<VersionInfo>
      */
     public static final VersionInfo UNICODE_13_0;
 
+    /**
+     * Unicode 14.0 version
+     * @stable ICU 70
+     */
+    public static final VersionInfo UNICODE_14_0;
+
+    /**
+     * Unicode 15.0 version
+     * @stable ICU 72
+     */
+    public static final VersionInfo UNICODE_15_0;
+
     /**
      * ICU4J current release version
      * @stable ICU 2.8
@@ -212,7 +224,7 @@ public final class VersionInfo implements Comparable<VersionInfo>
      * @deprecated This API is ICU internal only.
      */
     @Deprecated
-    public static final String ICU_DATA_VERSION_PATH = "68b";
+    public static final String ICU_DATA_VERSION_PATH = "73b";
 
     /**
      * Data version in ICU4J.
@@ -552,10 +564,12 @@ public final class VersionInfo implements Comparable<VersionInfo>
         UNICODE_12_0   = getInstance(12, 0, 0, 0);
         UNICODE_12_1   = getInstance(12, 1, 0, 0);
         UNICODE_13_0   = getInstance(13, 0, 0, 0);
+        UNICODE_14_0   = getInstance(14, 0, 0, 0);
+        UNICODE_15_0   = getInstance(15, 0, 0, 0);
 
-        ICU_VERSION   = getInstance(68, 2, 0, 0);
+        ICU_VERSION   = getInstance(73, 2, 0, 0);
         ICU_DATA_VERSION = ICU_VERSION;
-        UNICODE_VERSION = UNICODE_13_0;
+        UNICODE_VERSION = UNICODE_15_0;
 
         UCOL_RUNTIME_VERSION = getInstance(9);
         UCOL_BUILDER_VERSION = getInstance(9);
