@@ -341,7 +341,9 @@ public class CollationServiceTest extends TestFmwk {
 
     private static final String KWVAL[] = {
         "phonebook",
-        "stroke"
+        "stroke",
+        "emoji",
+        "eor",
     };
 
     @Test
@@ -385,20 +387,20 @@ public class CollationServiceTest extends TestFmwk {
         final String DATA[] = {
                           "sv", "sv", "t",
                           "sv@collation=direct", "sv", "t",
-                          "sv@collation=traditional", "sv", "t",
+                          "sv@collation=traditional", "sv@collation=traditional", "t",
                           "sv@collation=gb2312han", "sv", "t",
                           "sv@collation=stroke", "sv", "t",
                           "sv@collation=pinyin", "sv", "t",
-                          "sv@collation=standard", "sv@collation=standard", "t",
+                          "sv@collation=standard", "sv", "t",
                           "sv@collation=reformed", "sv", "t",
                           "sv@collation=big5han", "sv", "t",
                           "sv_FI", "sv", "f",
                           "sv_FI@collation=direct", "sv", "f",
-                          "sv_FI@collation=traditional", "sv", "f",
+                          "sv_FI@collation=traditional", "sv@collation=traditional", "f",
                           "sv_FI@collation=gb2312han", "sv", "f",
                           "sv_FI@collation=stroke", "sv", "f",
                           "sv_FI@collation=pinyin", "sv", "f",
-                          "sv_FI@collation=standard", "sv@collation=standard", "f",
+                          "sv_FI@collation=standard", "sv", "f",
                           "sv_FI@collation=reformed", "sv", "f",
                           "sv_FI@collation=big5han", "sv", "f",
                           "nl", "root", "t",
