@@ -387,7 +387,7 @@ public class GlobalizationPreferencesTest extends TestFmwk {
 //        gp.setLocale(new ULocale("ko_KR"));
 //        boolean bException = false;
 //        try {
-//            logln("Set invlaid accept-language - ko=100");
+//            logln("Set invalid accept-language - ko=100");
 //            gp.setLocales("ko=100");
 //        } catch (IllegalArgumentException iae) {
 //            logln("IllegalArgumentException was thrown");
@@ -421,7 +421,7 @@ public class GlobalizationPreferencesTest extends TestFmwk {
                 errln("FAIL: from_en_US is not from en_US bundle");
             }
         } catch (MissingResourceException mre) {
-            errln("FAIL: Missing resouces");
+            errln("FAIL: Missing resources");
         }
 
         gp.reset();
@@ -441,7 +441,7 @@ public class GlobalizationPreferencesTest extends TestFmwk {
                 errln("FAIL: from_en_US is not from en_US bundle");
             }
         } catch (MissingResourceException mre) {
-            errln("FAIL: Missing resouces");
+            errln("FAIL: Missing resources");
         }
 
         logln("Get a resource bundle which does not exist");
@@ -478,7 +478,7 @@ public class GlobalizationPreferencesTest extends TestFmwk {
         }
 
 
-        // Set explicity territory
+        // Set explicit territory
         logln("Set explicit territory - CA");
         gp.setTerritory("CA");
         territory = gp.getTerritory();
@@ -612,7 +612,7 @@ public class GlobalizationPreferencesTest extends TestFmwk {
             errln("FAIL: Currency is " + code + " - Expected: BRL");
         }
 
-        // Set ecplicit currency
+        // Set explicit currency
         gp1.setCurrency(ecur2);
         cur = gp1.getCurrency();
         code = cur.getCurrencyCode();
@@ -648,7 +648,7 @@ public class GlobalizationPreferencesTest extends TestFmwk {
             errln("FAIL: Calendar locale is " + calLocale.toString() + " - Expected: en_GB");
         }
 
-        // Set ecplicit calendar
+        // Set explicit calendar
         logln("Set Japanese calendar to this object");
         JapaneseCalendar jcal = new JapaneseCalendar();
         gp.setCalendar(jcal);
