@@ -1273,7 +1273,7 @@ public class DateFormatRegressionTest extends TestFmwk {
     @Test
     public void TestT10110() {
         try {
-            SimpleDateFormat formatter = new SimpleDateFormat("Gy年M月d日E", new Locale("zh_Hans"));
+            SimpleDateFormat formatter = new SimpleDateFormat("Gy年M月d日E", Locale.forLanguageTag("zh-Hans"));
             /* Object parsed = */ formatter.parseObject("610000");
         }
         catch(ParseException pe) {
