@@ -18,6 +18,7 @@ import org.junit.runner.RunWith;
 import org.junit.runners.JUnit4;
 
 import com.ibm.icu.dev.test.TestFmwk;
+import com.ibm.icu.text.ConstrainedFieldPosition;
 import com.ibm.icu.text.ListFormatter;
 import com.ibm.icu.text.ListFormatter.FormattedList;
 import com.ibm.icu.text.ListFormatter.Type;
@@ -193,9 +194,9 @@ public class ListFormatterTest extends TestFmwk {
     }
 
 
-    void DoTheRealListStyleTesting(ULocale locale, String items[], ListFormatter.Style style, String expected) {
-        ListFormatter listFormatter = ListFormatter.getInstance(locale, style);
-        assertEquals("Style \"" + style + "\"", expected, listFormatter.format((Object[])items));
+    void DoTheRealListStyleTesting(ULocale locale, String items[], ListFormatter.Type type, ListFormatter.Width width, String expected) {
+        ListFormatter listFormatter = ListFormatter.getInstance(locale, type, width);
+        assertEquals("Style \"" + type + "/" + width + "\"", expected, listFormatter.format((Object[])items));
     }
 
     @Test
@@ -203,11 +204,11 @@ public class ListFormatterTest extends TestFmwk {
         ULocale locale = ULocale.FRENCH;
         String[] input = { "rouge", "jaune", "bleu", "vert" };
 
-        DoTheRealListStyleTesting(locale, input, ListFormatter.Style.STANDARD, "rouge, jaune, bleu et vert");
-        DoTheRealListStyleTesting(locale, input, ListFormatter.Style.OR, "rouge, jaune, bleu ou vert");
-        DoTheRealListStyleTesting(locale, input, ListFormatter.Style.UNIT, "rouge, jaune, bleu et vert");
-        DoTheRealListStyleTesting(locale, input, ListFormatter.Style.UNIT_NARROW, "rouge jaune bleu vert");
-        DoTheRealListStyleTesting(locale, input, ListFormatter.Style.UNIT_SHORT, "rouge, jaune, bleu et vert");
+        DoTheRealListStyleTesting(locale, input, ListFormatter.Type.AND, ListFormatter.Width.WIDE, "rouge, jaune, bleu et vert");
+        DoTheRealListStyleTesting(locale, input, ListFormatter.Type.OR, ListFormatter.Width.WIDE, "rouge, jaune, bleu ou vert");
+        DoTheRealListStyleTesting(locale, input, ListFormatter.Type.UNITS, ListFormatter.Width.WIDE, "rouge, jaune, bleu et vert");
+        DoTheRealListStyleTesting(locale, input, ListFormatter.Type.UNITS, ListFormatter.Width.NARROW, "rouge jaune bleu vert");
+        DoTheRealListStyleTesting(locale, input, ListFormatter.Type.UNITS, ListFormatter.Width.SHORT, "rouge, jaune, bleu et vert");
     }
 
     private boolean isDefaultLocaleEnglishLike() {
@@ -262,15 +263,15 @@ public class ListFormatterTest extends TestFmwk {
                 {ListFormatter.Field.ELEMENT, 2, 9},
                 {ListFormatter.SpanField.LIST_SPAN, 9, 12, 2},
                 {ListFormatter.Field.ELEMENT, 9, 12}};
-            if (!logKnownIssue("21351", "Java still coalesces adjacent elements")) {
-                FormattedValueTest.checkFormattedValue(
-                    message,
-                    result,
-                    expectedString,
-                    expectedFieldPositions);
-            }
+            FormattedValueTest.checkFormattedValue(
+                message,
+                result,
+                expectedString,
+                expectedFieldPositions,
+                // Adjacent fields: skip AttributedCharacterIterator test
+                true);
         }
-    
+
         {
             ListFormatter fmt = ListFormatter.getInstance(ULocale.ENGLISH, Type.UNITS, Width.SHORT);
             String message = "ICU-21383 Long list";
@@ -432,4 +433,27 @@ public class ListFormatterTest extends TestFmwk {
             }
         }
     }
+
+    @Test
+    public void Test21871() {
+        ListFormatter fmt = ListFormatter.getInstance(ULocale.ENGLISH, Type.AND, Width.WIDE);
+        {
+            FormattedList result = fmt.formatToValue("A", "");
+            ConstrainedFieldPosition cfp = new ConstrainedFieldPosition();
+            cfp.constrainField(ListFormatter.Field.ELEMENT);
+            assertTrue("nextPosition 1", result.nextPosition(cfp));
+            assertEquals("start", cfp.getStart(), 0);
+            assertEquals("limit", cfp.getLimit(), 1);
+            assertFalse("nextPosition 2", result.nextPosition(cfp));
+        }
+        {
+            FormattedList result = fmt.formatToValue("", "B");
+            ConstrainedFieldPosition cfp = new ConstrainedFieldPosition();
+            cfp.constrainField(ListFormatter.Field.ELEMENT);
+            assertTrue("nextPosition 1", result.nextPosition(cfp));
+            assertEquals("start", cfp.getStart(), 5);
+            assertEquals("limit", cfp.getLimit(), 6);
+            assertFalse("nextPosition 2", result.nextPosition(cfp));
+        }
+    }
 }
