@@ -115,7 +115,7 @@ public class TimeUnitTest extends TestFmwk {
         format.setLocale(es);
         formatParsing(format);
 
-        format.setLocale(new Locale("pt_BR"));
+        format.setLocale(new Locale("pt", "BR"));
         formatParsing(format);
         format = new TimeUnitFormat(new Locale("de"));
         formatParsing(format);
@@ -182,8 +182,8 @@ public class TimeUnitTest extends TestFmwk {
                 "1 έτος",
                 // "el_GR" 1 short
                 "1 δευτ.",
-                "1 λεπ.",
-                "1 ώρα",
+                "1 λ.",
+                "1 ώ.",
                 "1 ημέρα",
                 "1 εβδ.",
                 "1 μήν.",
@@ -198,8 +198,8 @@ public class TimeUnitTest extends TestFmwk {
                 "7 έτη",
                 // "el_GR" 7 short
                 "7 δευτ.",
-                "7 λεπ.",
-                "7 ώρ.",		    // hour (other)
+                "7 λ.",
+                "7 ώ.",		        // hour (other)
                 "7 ημέρες",
                 "7 εβδ.",
                 "7 μήν.",
@@ -214,8 +214,8 @@ public class TimeUnitTest extends TestFmwk {
                 "1 έτος",
                 // "el" 1 short
                 "1 δευτ.",
-                "1 λεπ.",
-                "1 ώρα",
+                "1 λ.",
+                "1 ώ.",
                 "1 ημέρα",
                 "1 εβδ.",
                 "1 μήν.",
@@ -230,8 +230,8 @@ public class TimeUnitTest extends TestFmwk {
                 "7 έτη",
                 // "el" 7 short
                 "7 δευτ.",
-                "7 λεπ.",
-                "7 ώρ.",		    // hour (other)
+                "7 λ.",
+                "7 ώ.",		        // hour (other)
                 "7 ημέρες",
                 "7 εβδ.",
                 "7 μήν.",
@@ -269,10 +269,10 @@ public class TimeUnitTest extends TestFmwk {
      * Performs tests for Greek.
      * This tests that if the plural count listed in time unit format does not
      * match those in the plural rules for the locale, those plural count in
-     * time unit format will be ingored and subsequently, fall back will kick in
+     * time unit format will be ignored and subsequently, fall back will kick in
      * which is tested above.
      * Without data sanitization, setNumberFormat() would crash.
-     * As of CLDR shiped in ICU4.8, Greek is one such language.
+     * As of CLDR shipped in ICU4.8, Greek is one such language.
      */
     @Test
     public void TestGreekWithSanitization() {
@@ -343,7 +343,7 @@ public class TimeUnitTest extends TestFmwk {
         }
         for (int i = 0; i < cases.length; i++) {
             try {
-                TimeUnitFormat tuf = new TimeUnitFormat(new Locale("en_US"), cases[i]);
+                TimeUnitFormat tuf = new TimeUnitFormat(new Locale("en", "US"), cases[i]);
                 errln("TimeUnitFormat(ULocale,int) was suppose to return an " + "exception for a style value of "
                         + cases[i] + "passed into the constructor.");
             } catch (Exception e) {
@@ -358,7 +358,7 @@ public class TimeUnitTest extends TestFmwk {
     public void TestSetLocale() {
         // Tests when "if ( locale != this.locale )" is false
         TimeUnitFormat tuf = new TimeUnitFormat(new ULocale("en_US"));
-        if (!tuf.setLocale(new ULocale("en_US")).equals(tuf) && !tuf.setLocale(new Locale("en_US")).equals(tuf)) {
+        if (!tuf.setLocale(new ULocale("en_US")).equals(tuf) && !tuf.setLocale(new Locale("en", "US")).equals(tuf)) {
             errln("TimeUnitFormat.setLocale(ULocale) was suppose to "
                     + "return the same TimeUnitFormat object if the same " + "ULocale is entered as a parameter.");
         }
