@@ -391,7 +391,7 @@ public final class StringTokenizerTest extends TestFmwk
 
         tokenizer = new StringTokenizer(str, "q", true);
         if (!tokenizer.nextElement().equals(str)) {
-            errln("Should have recieved the same string when there are no delimiters");
+            errln("Should have received the same string when there are no delimiters");
         }
     }
 
@@ -562,12 +562,12 @@ public final class StringTokenizerTest extends TestFmwk
             us._generatePattern(sb.append(1.0), true);
             us._generatePattern(sb.reverse(), true);
         } catch(Exception e){
-            errln("UnicodeSet._generatePattern is not suppose to return an exception.");
+            errln("UnicodeSet._generatePattern is not supposed to return an exception.");
         }
 
         try{
             us._generatePattern(null, true);
-            errln("UnicodeSet._generatePattern is suppose to return an exception.");
+            errln("UnicodeSet._generatePattern is supposed to return an exception.");
         } catch(Exception e){}
     }
 
@@ -585,12 +585,12 @@ public final class StringTokenizerTest extends TestFmwk
         int limit = 0;
 
         if(us.matches(null, offset, limit, true) != UnicodeSet.U_PARTIAL_MATCH){
-            errln("UnicodeSet.matches is suppose to return " + UnicodeSet.U_PARTIAL_MATCH +
+            errln("UnicodeSet.matches is supposed to return " + UnicodeSet.U_PARTIAL_MATCH +
                     " but got " + us.matches(null, offset, limit, true));
         }
 
         if(us.matches(null, offset, limit, false) != UnicodeSet.U_MATCH){
-            errln("UnicodeSet.matches is suppose to return " + UnicodeSet.U_MATCH +
+            errln("UnicodeSet.matches is supposed to return " + UnicodeSet.U_MATCH +
                     " but got " + us.matches(null, offset, limit, false));
         }
 
@@ -601,7 +601,7 @@ public final class StringTokenizerTest extends TestFmwk
             offset[0] = 4; // Takes the letter "y"
             us.matches(rs, offset, 1, true);
         } catch(Exception e) {
-            errln("UnicodeSet.matches is not suppose to return an exception");
+            errln("UnicodeSet.matches is not supposed to return an exception");
         }
 
         // TODO: Tests when "if (forward && length < highWaterLength)" is true
@@ -650,7 +650,7 @@ public final class StringTokenizerTest extends TestFmwk
         for(int i=0; i < invalid.length; i++){
             try{
                 us.indexOf(invalid[i]);
-                errln("UnicodeSet.indexOf is suppose to return an exception " +
+                errln("UnicodeSet.indexOf is supposed to return an exception " +
                         "for a value of " + invalid[i]);
             } catch(Exception e){}
         }
@@ -659,7 +659,7 @@ public final class StringTokenizerTest extends TestFmwk
             try{
                 us.indexOf(valid[i]);
             } catch(Exception e){
-                errln("UnicodeSet.indexOf is not suppose to return an exception " +
+                errln("UnicodeSet.indexOf is not supposed to return an exception " +
                         "for a value of " + valid[i]);
             }
         }
@@ -676,7 +676,7 @@ public final class StringTokenizerTest extends TestFmwk
         int[] invalid = {-100,-10,-5,-2,-1};
         for(int i=0; i < invalid.length; i++){
             if(us.charAt(invalid[i]) != -1){
-                errln("UnicodeSet.charAt(int index) was suppose to return -1 "
+                errln("UnicodeSet.charAt(int index) was supposed to return -1 "
                         + "for an invalid input of " + invalid[i]);
             }
         }
@@ -696,7 +696,7 @@ public final class StringTokenizerTest extends TestFmwk
          for(int i=0; i < invalid.length; i++){
              try{
                  us.add(invalid[i], UnicodeSet.MAX_VALUE);
-                 errln("UnicodeSet.add(int start, int end) was suppose to give "
+                 errln("UnicodeSet.add(int start, int end) was supposed to give "
                          + "an exception for an start invalid input of "
                          + invalid[i]);
              } catch (Exception e){}
@@ -706,7 +706,7 @@ public final class StringTokenizerTest extends TestFmwk
          for(int i=0; i < invalid.length; i++){
              try{
                  us.add(UnicodeSet.MIN_VALUE, invalid[i]);
-                 errln("UnicodeSet.add(int start, int end) was suppose to give "
+                 errln("UnicodeSet.add(int start, int end) was supposed to give "
                          + "an exception for an end invalid input of "
                          + invalid[i]);
              } catch (Exception e){}
@@ -714,12 +714,12 @@ public final class StringTokenizerTest extends TestFmwk
 
          // Tests when "else if (start == end)" is false
          if(!(us.add(UnicodeSet.MIN_VALUE+1, UnicodeSet.MIN_VALUE).equals(us)))
-             errln("UnicodeSet.add(int start, int end) was suppose to return "
+             errln("UnicodeSet.add(int start, int end) was supposed to return "
                      + "the same object because start of value " + (UnicodeSet.MIN_VALUE+1)
                      + " is greater than end of value " + UnicodeSet.MIN_VALUE);
 
          if(!(us.add(UnicodeSet.MAX_VALUE, UnicodeSet.MAX_VALUE-1).equals(us)))
-             errln("UnicodeSet.add(int start, int end) was suppose to return "
+             errln("UnicodeSet.add(int start, int end) was supposed to return "
                      + "the same object because start of value " + UnicodeSet.MAX_VALUE
                      + " is greater than end of value " + (UnicodeSet.MAX_VALUE-1));
      }
@@ -738,7 +738,7 @@ public final class StringTokenizerTest extends TestFmwk
          for(int i=0; i < invalid.length; i++){
              try{
                  us.add(invalid[i]);
-                 errln("UnicodeSet.add(int c) was suppose to give "
+                 errln("UnicodeSet.add(int c) was supposed to give "
                          + "an exception for an start invalid input of "
                          + invalid[i]);
              } catch (Exception e){}
@@ -758,14 +758,15 @@ public final class StringTokenizerTest extends TestFmwk
          // Tests when "if (s.length() < 1)" is true
          try{
              us.contains("");
-             errln("UnicodeSet.getSingleCP is suppose to give an exception for " +
+         } catch (Exception e) {
+             errln("UnicodeSet.getSingleCP is not supposed to give an exception for " +
                      "an empty string.");
-         } catch (Exception e){}
+         }
 
          try{
              us.contains((String)null);
-             errln("UnicodeSet.getSingleCP is suppose to give an exception for " +
-             "a null string.");
+             errln("UnicodeSet.getSingleCP is supposed to give an exception for " +
+                     "a null string.");
          } catch (Exception e){}
 
          // Tests when "if (cp > 0xFFFF)" is true
@@ -774,8 +775,8 @@ public final class StringTokenizerTest extends TestFmwk
              try{
                  us.contains(cases[i]);
              } catch (Exception e){
-                 errln("UnicodeSet.getSingleCP is not suppose to give an exception for " +
-                     "a null string.");
+                 errln("UnicodeSet.getSingleCP is not supposed to give an exception for " +
+                     "a surrogate pair.");
              }
          }
      }
@@ -790,7 +791,7 @@ public final class StringTokenizerTest extends TestFmwk
          try{
              us.removeAllStrings();
          } catch(Exception e){
-             errln("UnicodeSet.removeAllString() was not suppose to given an " +
+             errln("UnicodeSet.removeAllString() was not supposed to given an " +
                      "exception for a strings size of 0");
          }
      }
@@ -808,7 +809,7 @@ public final class StringTokenizerTest extends TestFmwk
           for(int i=0; i < invalid.length; i++){
               try{
                   us.retain(invalid[i], UnicodeSet.MAX_VALUE);
-                  errln("UnicodeSet.retain(int start, int end) was suppose to give "
+                  errln("UnicodeSet.retain(int start, int end) was supposed to give "
                           + "an exception for an start invalid input of "
                           + invalid[i]);
               } catch (Exception e){}
@@ -818,7 +819,7 @@ public final class StringTokenizerTest extends TestFmwk
           for(int i=0; i < invalid.length; i++){
               try{
                   us.retain(UnicodeSet.MIN_VALUE, invalid[i]);
-                  errln("UnicodeSet.retain(int start, int end) was suppose to give "
+                  errln("UnicodeSet.retain(int start, int end) was supposed to give "
                           + "an exception for an end invalid input of "
                           + invalid[i]);
               } catch (Exception e){}
@@ -828,14 +829,14 @@ public final class StringTokenizerTest extends TestFmwk
           try{
               us.retain(UnicodeSet.MIN_VALUE+1, UnicodeSet.MIN_VALUE);
           } catch(Exception e){
-              errln("UnicodeSet.retain(int start, int end) was not suppose to give "
+              errln("UnicodeSet.retain(int start, int end) was not supposed to give "
                       + "an exception.");
           }
 
           try{
               us.retain(UnicodeSet.MAX_VALUE, UnicodeSet.MAX_VALUE-1);
           } catch(Exception e){
-              errln("UnicodeSet.retain(int start, int end) was not suppose to give "
+              errln("UnicodeSet.retain(int start, int end) was not supposed to give "
                       + "an exception.");
           }
       }
@@ -849,7 +850,7 @@ public final class StringTokenizerTest extends TestFmwk
           UnicodeSet us = new UnicodeSet();
           us.add("dummy");
           if(!(us.retain("dummy").equals(us))){
-              errln("UnicodeSet.retain(String s) was suppose to return the " +
+              errln("UnicodeSet.retain(String s) was supposed to return the " +
                       "same UnicodeSet since the string was found in the original.");
           }
       }
@@ -867,7 +868,7 @@ public final class StringTokenizerTest extends TestFmwk
            for(int i=0; i < invalid.length; i++){
                try{
                    us.remove(invalid[i], UnicodeSet.MAX_VALUE);
-                   errln("UnicodeSet.remove(int start, int end) was suppose to give "
+                   errln("UnicodeSet.remove(int start, int end) was supposed to give "
                            + "an exception for an start invalid input of "
                            + invalid[i]);
                } catch (Exception e){}
@@ -877,7 +878,7 @@ public final class StringTokenizerTest extends TestFmwk
            for(int i=0; i < invalid.length; i++){
                try{
                    us.remove(UnicodeSet.MIN_VALUE, invalid[i]);
-                   errln("UnicodeSet.remove(int start, int end) was suppose to give "
+                   errln("UnicodeSet.remove(int start, int end) was supposed to give "
                            + "an exception for an end invalid input of "
                            + invalid[i]);
                } catch (Exception e){}
@@ -887,14 +888,14 @@ public final class StringTokenizerTest extends TestFmwk
            try{
                us.remove(UnicodeSet.MIN_VALUE+1, UnicodeSet.MIN_VALUE);
            } catch(Exception e){
-               errln("UnicodeSet.remove(int start, int end) was not suppose to give "
+               errln("UnicodeSet.remove(int start, int end) was not supposed to give "
                        + "an exception.");
            }
 
            try{
                us.remove(UnicodeSet.MAX_VALUE, UnicodeSet.MAX_VALUE-1);
            } catch(Exception e){
-               errln("UnicodeSet.remove(int start, int end) was not suppose to give "
+               errln("UnicodeSet.remove(int start, int end) was not supposed to give "
                        + "an exception.");
            }
        }
@@ -912,7 +913,7 @@ public final class StringTokenizerTest extends TestFmwk
             for(int i=0; i < invalid.length; i++){
                 try{
                     us.complement(invalid[i], UnicodeSet.MAX_VALUE);
-                    errln("UnicodeSet.complement(int start, int end) was suppose to give "
+                    errln("UnicodeSet.complement(int start, int end) was supposed to give "
                             + "an exception for an start invalid input of "
                             + invalid[i]);
                 } catch (Exception e){}
@@ -922,7 +923,7 @@ public final class StringTokenizerTest extends TestFmwk
             for(int i=0; i < invalid.length; i++){
                 try{
                     us.complement(UnicodeSet.MIN_VALUE, invalid[i]);
-                    errln("UnicodeSet.complement(int start, int end) was suppose to give "
+                    errln("UnicodeSet.complement(int start, int end) was supposed to give "
                             + "an exception for an end invalid input of "
                             + invalid[i]);
                 } catch (Exception e){}
@@ -932,14 +933,14 @@ public final class StringTokenizerTest extends TestFmwk
             try{
                 us.complement(UnicodeSet.MIN_VALUE+1, UnicodeSet.MIN_VALUE);
             } catch(Exception e){
-                errln("UnicodeSet.complement(int start, int end) was not suppose to give "
+                errln("UnicodeSet.complement(int start, int end) was not supposed to give "
                         + "an exception.");
             }
 
             try{
                 us.complement(UnicodeSet.MAX_VALUE, UnicodeSet.MAX_VALUE-1);
             } catch(Exception e){
-                errln("UnicodeSet.complement(int start, int end) was not suppose to give "
+                errln("UnicodeSet.complement(int start, int end) was not supposed to give "
                         + "an exception.");
             }
         }
@@ -955,7 +956,7 @@ public final class StringTokenizerTest extends TestFmwk
             try{
                 us.complement("dummy");
             } catch (Exception e){
-                errln("UnicodeSet.complement(String s) was not suppose to give "
+                errln("UnicodeSet.complement(String s) was not supposed to give "
                         + "an exception for 'dummy'.");
             }
 
@@ -965,7 +966,7 @@ public final class StringTokenizerTest extends TestFmwk
             try{
                 us.complement("\uDC11");
             } catch (Exception e){
-                errln("UnicodeSet.complement(String s) was not suppose to give "
+                errln("UnicodeSet.complement(String s) was not supposed to give "
                         + "an exception for '\uDC11'.");
             }
         }
@@ -983,7 +984,7 @@ public final class StringTokenizerTest extends TestFmwk
             for(int i=0; i < invalid.length; i++){
                 try{
                     us.contains(invalid[i]);
-                    errln("UnicodeSet.contains(int c) was suppose to give "
+                    errln("UnicodeSet.contains(int c) was supposed to give "
                             + "an exception for an start invalid input of "
                             + invalid[i]);
                 } catch (Exception e){}
@@ -1003,7 +1004,7 @@ public final class StringTokenizerTest extends TestFmwk
              for(int i=0; i < invalid.length; i++){
                  try{
                      us.contains(invalid[i], UnicodeSet.MAX_VALUE);
-                     errln("UnicodeSet.contains(int start, int end) was suppose to give "
+                     errln("UnicodeSet.contains(int start, int end) was supposed to give "
                              + "an exception for an start invalid input of "
                              + invalid[i]);
                  } catch (Exception e){}
@@ -1013,7 +1014,7 @@ public final class StringTokenizerTest extends TestFmwk
              for(int i=0; i < invalid.length; i++){
                  try{
                      us.contains(UnicodeSet.MIN_VALUE, invalid[i]);
-                     errln("UnicodeSet.contains(int start, int end) was suppose to give "
+                     errln("UnicodeSet.contains(int start, int end) was supposed to give "
                              + "an exception for an end invalid input of "
                              + invalid[i]);
                  } catch (Exception e){}
@@ -1028,7 +1029,7 @@ public final class StringTokenizerTest extends TestFmwk
              UnicodeSet us = new UnicodeSet();
              String res = us.getRegexEquivalent();
              if(!(res.equals("[]")))
-                 errln("UnicodeSet.getRegexEquivalent is suppose to return '[]' " +
+                 errln("UnicodeSet.getRegexEquivalent is supposed to return '[]' " +
                          "but got " + res);
          }
 
@@ -1045,7 +1046,7 @@ public final class StringTokenizerTest extends TestFmwk
               for(int i=0; i < invalid.length; i++){
                   try{
                       us.containsNone(invalid[i], UnicodeSet.MAX_VALUE);
-                      errln("UnicodeSet.containsNoneint start, int end) was suppose to give "
+                      errln("UnicodeSet.containsNoneint start, int end) was supposed to give "
                               + "an exception for an start invalid input of "
                               + invalid[i]);
                   } catch (Exception e){}
@@ -1055,7 +1056,7 @@ public final class StringTokenizerTest extends TestFmwk
               for(int i=0; i < invalid.length; i++){
                   try{
                       us.containsNone(UnicodeSet.MIN_VALUE, invalid[i]);
-                      errln("UnicodeSet.containsNone(int start, int end) was suppose to give "
+                      errln("UnicodeSet.containsNone(int start, int end) was supposed to give "
                               + "an exception for an end invalid input of "
                               + invalid[i]);
                   } catch (Exception e){}
@@ -1066,7 +1067,7 @@ public final class StringTokenizerTest extends TestFmwk
                   us.add(0);
                   us.containsNone(1, 2); // 1 > 0
               } catch (Exception e){
-                  errln("UnicodeSet.containsNone(int start, int end) was not suppose to give " +
+                  errln("UnicodeSet.containsNone(int start, int end) was not supposed to give " +
                           "an exception.");
               }
           }
