@@ -12,22 +12,17 @@ import java.lang.reflect.Constructor;
 import java.lang.reflect.Method;
 import java.lang.reflect.Modifier;
 import java.security.Policy;
-import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.List;
 import java.util.Locale;
-import java.util.Map;
 import java.util.Properties;
 import java.util.Random;
-import java.util.TreeMap;
+import java.util.TimeZone;
 
 import org.junit.After;
+import org.junit.AfterClass;
 import org.junit.Assert;
 import org.junit.Before;
 
-import com.ibm.icu.util.TimeZone;
-import com.ibm.icu.util.ULocale;
-
 /**
  * TestFmwk is a base class for tests that can be run conveniently from the
  * command line as well as under the Java test harness.
@@ -97,7 +92,7 @@ abstract public class TestFmwk extends AbstractTestLog {
 
     /**
      * This method is called at the beginning of {@link #testTeardown()}.
-     * TestFmwk implementation class hould override this method, instead
+     * TestFmwk implementation class should override this method, instead
      * of annotating After.
      */
     protected void localTestTeardown() {
@@ -112,6 +107,17 @@ abstract public class TestFmwk extends AbstractTestLog {
         }
     }
 
+    @AfterClass
+    public final static void testClassTeardown() {
+        getParams().knownIssues.printKnownIssues(new UnicodeKnownIssues.Consumer<String>() {
+            // TODO: make this a Lambda once JDK 1.8 ships
+            public void accept(String t) {
+                System.out.println(t);
+            }
+        });
+        getParams().knownIssues.reset();
+    }
+
     private static TestParams getParams() {
         //return paramsReference.get();
         return testParams;
@@ -170,10 +176,6 @@ abstract public class TestFmwk extends AbstractTestLog {
 
     }
 
-    static final String ICU_TRAC_URL = "http://bugs.icu-project.org/trac/ticket/";
-    static final String CLDR_TRAC_URL = "http://unicode.org/cldr/trac/ticket/";
-    static final String CLDR_TICKET_PREFIX = "cldrbug:";
-
     /**
      * Log the known issue.
      * This method returns true unless -prop:logKnownIssue=no is specified
@@ -189,41 +191,12 @@ abstract public class TestFmwk extends AbstractTestLog {
         if (!getBooleanProperty("logKnownIssue", true)) {
             return false;
         }
-
         // TODO: This method currently does not do very much.
-        // See http://bugs.icu-project.org/trac/ticket/12589
-
-        StringBuffer descBuf = new StringBuffer();
+        // See https://unicode-org.atlassian.net/browse/ICU-12589
         // TODO(junit) : what to do about this?
+        final String path = "";
         //getParams().stack.appendPath(descBuf);
-        if (comment != null && comment.length() > 0) {
-            descBuf.append(" (" + comment + ")");
-        }
-        String description = descBuf.toString();
-
-        String ticketLink = "Unknown Ticket";
-        if (ticket != null && ticket.length() > 0) {
-            boolean isCldr = false;
-            ticket = ticket.toLowerCase(Locale.ENGLISH);
-            if (ticket.startsWith(CLDR_TICKET_PREFIX)) {
-                isCldr = true;
-                ticket = ticket.substring(CLDR_TICKET_PREFIX.length());
-            }
-            ticketLink = (isCldr ? CLDR_TRAC_URL : ICU_TRAC_URL) + ticket;
-        }
-
-        if (getParams().knownIssues == null) {
-            getParams().knownIssues = new TreeMap<String, List<String>>();
-        }
-        List<String> lines = getParams().knownIssues.get(ticketLink);
-        if (lines == null) {
-            lines = new ArrayList<String>();
-            getParams().knownIssues.put(ticketLink, lines);
-        }
-        if (!lines.contains(description)) {
-            lines.add(description);
-        }
-
+        getParams().knownIssues.logKnownIssue(path, ticket, comment);
         return true;
     }
 
@@ -247,19 +220,6 @@ abstract public class TestFmwk extends AbstractTestLog {
         return getParams().getIntProperty(key, defVal, maxVal);
     }
 
-    protected static TimeZone safeGetTimeZone(String id) {
-        TimeZone tz = TimeZone.getTimeZone(id);
-        if (tz == null) {
-            // should never happen
-            errln("FAIL: TimeZone.getTimeZone(" + id + ") => null");
-        }
-        if (!tz.getID().equals(id)) {
-            warnln("FAIL: TimeZone.getTimeZone(" + id + ") => " + tz.getID());
-        }
-        return tz;
-    }
-
-
     // Utility Methods
 
     protected static String hex(char[] s){
@@ -365,7 +325,7 @@ abstract public class TestFmwk extends AbstractTestLog {
         private SecurityManager testSecurityManager;
         private SecurityManager originalSecurityManager;
 
-        private Map<String, List<String>> knownIssues;
+        private UnicodeKnownIssues knownIssues = null;
 
         private Properties props;
 
@@ -377,6 +337,7 @@ abstract public class TestFmwk extends AbstractTestLog {
             TestParams params = new TestParams();
             Properties props = System.getProperties();
             params.parseProperties(props);
+            params.knownIssues = new UnicodeKnownIssues(params.getBooleanProperty("allKnownIssues", false));
             return params;
         }
 
@@ -506,6 +467,9 @@ abstract public class TestFmwk extends AbstractTestLog {
      * Check the given array to see that all the locales in the expected array
      * are present.
      *
+     * @param <T>
+     *            the type of the objects to check, must have a toString method,
+     *            so anything will do
      * @param msg
      *            string message, for log output
      * @param array
@@ -514,27 +478,7 @@ abstract public class TestFmwk extends AbstractTestLog {
      *            array of locales names we expect to see, or null
      * @return the length of 'array'
      */
-    protected static int checkArray(String msg, Locale array[], String expected[]) {
-        String strs[] = new String[array.length];
-        for (int i = 0; i < array.length; ++i) {
-            strs[i] = array[i].toString();
-        }
-        return checkArray(msg, strs, expected);
-    }
-
-    /**
-     * Check the given array to see that all the locales in the expected array
-     * are present.
-     *
-     * @param msg
-     *            string message, for log output
-     * @param array
-     *            array of locales to check
-     * @param expected
-     *            array of locales names we expect to see, or null
-     * @return the length of 'array'
-     */
-    protected static int checkArray(String msg, ULocale array[], String expected[]) {
+    protected static <T> int checkArray(String msg, T array[], String expected[]) {
         String strs[] = new String[array.length];
         for (int i = 0; i < array.length; ++i) {
             strs[i] = array[i].toString();
@@ -791,5 +735,4 @@ abstract public class TestFmwk extends AbstractTestLog {
 //            System.out.println();
 //        }
     }
-
 }
